# $Id: Document.pm 35761 2011-10-12 18:45:02Z wsl $
# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Status/Document.pm $

use strict;
use warnings FATAL => 'all';
use utf8;

package Aselect::UI::Status::Document;

use Aselect::UI::Document -self;

sub build {
	$self->setDocumentElement($self->construct('status'));
}
